@@ -53,10 +53,7 @@ class PrintSpace():
             disabled: bool: behave like python default print_function
 
     """
-    def __init__(self,
-                 conf: Dict[str, dict] = None,
-                 /,
-                 name: str = None) -> None:
+    def __init__(self, conf: Dict[str, dict] = None, name: str = None) -> None:
         # Standard info styles
         self.switches = {
             'pad': False,
@@ -103,13 +100,17 @@ class PrintSpace():
         Returns:
             Infomark corresponding to mark
         """
-        if isinstance(mark, str):
-            return self.info_style[mark]
-        if isinstance(mark, int):
-            if not 0 <= mark < len(self.info_index):
-                mark = 0
+        try:
+            # check if mark can be converted to int index
+            mark = int(mark)
+        except ValueError:
+            if isinstance(mark, str):
+                return self.info_style.get(mark, self.info_style['cont'])
+        except Exception:
+            raise KeyError(mark)
+        if 0 <= mark < len(self.info_index):
             return self.info_style[self.info_index[mark]]
-        raise KeyError(mark)
+        return self.info_style[self.info_index[0]]
 
     def __iter__(self) -> Generator[Tuple[int, str, InfoMark], None, None]:
         for index_int, mark in enumerate(self.info_index):
@@ -127,7 +128,7 @@ class PrintSpace():
             return False
         return True
 
-    def set_opts(self, conf: Dict[str, dict], /, name: str) -> None:
+    def set_opts(self, conf: Dict[str, dict], name: str) -> None:
         """
         configuration from rcfile
 
@@ -219,7 +220,7 @@ class PrintSpace():
         self.info_style[mark] = InfoMark(pref_max=self.pref_max, **kwargs)
         return str(self)
 
-    def remove_style(self, mark: Union[str, int, InfoMark], /) -> str:
+    def remove_style(self, mark: Union[str, int, InfoMark]) -> str:
         """
         Args:
             mark: is popped out of defined styles
