@@ -71,7 +71,7 @@ class AnsiEffect():
         except KeyError:
             raise BadBGCol(bgcol) from None
 
-    def __eq__(self, other, /) -> bool:
+    def __eq__(self, other) -> bool:
         if any(
                 getattr(self, attr) != getattr(other, attr)
                 for attr in ('color', 'gloss', 'bgcol')):
@@ -161,7 +161,7 @@ class PrintPref():
             pad_len[idx] += max(pad_max[idx] - len(pref_type), 0)
         self.pad = [' ' * (span + 1) for span in pad_len]
 
-    def __eq__(self, other, /) -> bool:
+    def __eq__(self, other) -> bool:
         if any(
                 getattr(self, attr) != getattr(other, attr)
                 for attr in ('pad', 'brackets', 'pref', 'style')):
