@@ -49,7 +49,7 @@ class MyFmtClass():
                 fmt_out.extend(psfmt(line, mark='cont'))
         return '\n'.join(fmt_out)
 
-    def update(self, data: str, /):
+    def update(self, data: str):
         self.attr = data
 
 
