@@ -37,6 +37,14 @@ class TestPrintSpace(unittest.TestCase):
     def setUp(self):
         self.test_print = init_print()
 
+    def test_eq(self):
+        self.assertEqual(self.test_print, self.test_print)
+
+    def test_ne(self):
+        mod_print = init_print()
+        mod_print.edit_style('test', mark='test')
+        self.assertNotEqual(self.test_print, mod_print)
+
     def test_defaults_load(self):
         """
         print all default marks
